# discrimintools : Python library for discriminant analysis

## About discrimintools

discrimintools is a Python package dedicated to Discriminant Analysis (DA) distributed under the MIT License.

## Overview

Discriminant analysis is a classification problem, where two or more groups or clusters or populations are known _a priori_ and one or more new observations are classified into one of the known populations based on the measured characteristics.

## Why use discrimintools?

With this discrimintools package, you can perform :

* Canonical Discriminant Analysis (CANDISC)
* Linear Discriminant Analysis (LDA)
* Principal Components Analysis - Discriminant Analysis (PCADA)
* Discriminant Analysis for qualitatives/categoricals variables (DISQUAL)
* Discriminant Analysis of Mixed Data (DISMIX)
* Discriminant Correspondence Analysis (DISCA)
* Stepwise Discriminant Analysis (STEPDISC)

## Installation

### Dependencies

discrimintools requires 

```
Python >= 3.10
numpy >= 1.26.4
pandas >=2.2.2
scikit-learn >=1.2.2
polars >= 0.19.2
plotnine >= 0.10.1
mapply >= 0.1.21
scientisttools >= 0.1.4
statsmodels >= 0.14.0
scipy >= 1.10.1
```

### User installation

You can install discrimintools using pip :

```
pip install discrimintools
```

## Documentation

The docstring is written in english

## References

> [http://www.math.wpi.edu/saspdf/stat/chap25.pdf](http://www.math.wpi.edu/saspdf/stat/chap25.pdf)

> [https://support.sas.com/documentation/cdl/en/statugdiscrim/61779/PDF/default/statugdiscrim.pdf](https://support.sas.com/documentation/cdl/en/statugdiscrim/61779/PDF/default/statugdiscrim.pdf)

> [https://online.stat.psu.edu/stat505/lesson/10](https://online.stat.psu.edu/stat505/lesson/10)

> [https://eric.univ-lyon2.fr/ricco/cours/slides/analyse_discriminante.pdf](https://eric.univ-lyon2.fr/ricco/cours/slides/analyse_discriminante.pdf)

> [https://eric.univ-lyon2.fr/ricco/cours/cours/Pratique_Analyse_Discriminante_Lineaire.pdf](https://eric.univ-lyon2.fr/ricco/cours/cours/Pratique_Analyse_Discriminante_Lineaire.pdf)

## Authors

Duvérier DJIFCK ZEBAZE [duverierdjifack@gmail.com](mailto:duverierdjifack@gmail.com)
